==> Platform-1.0.2.zip: Platform-1.0.2/readme.md <==
## AsgardCMS Platform

View the documentation at [AsgardCMS.com/docs](http://asgardcms.com/docs/).

Join the conversation on Slack [![Slack](http://slack.asgardcms.com/badge.svg)](http://slack.asgardcms.com/)

## Builds

| Module | Master | Develop |
| ---------------- | --------------- | --------------- |
| [Core](https://github.com/AsgardCms/Core)  | [![Build Status](https://travis-ci.org/AsgardCms/Core.svg?branch=master)](https://travis-ci.org/AsgardCms/Core) | [![Build Status](https://travis-ci.org/AsgardCms/Core.svg?branch=develop)](https://travis-ci.org/AsgardCms/Core)
| [Setting](https://github.com/AsgardCms/Setting)  | [![Build Status](https://travis-ci.org/AsgardCms/Setting.svg?branch=master)](https://travis-ci.org/AsgardCms/Setting) | [![Build Status](https://travis-ci.org/AsgardCms/Setting.svg?branch=develop)](https://travis-ci.org/AsgardCms/Setting)
| [Menu](https://github.com/AsgardCms/Menu)  | [![Build Status](https://travis-ci.org/AsgardCms/Menu.svg?branch=master)](https://travis-ci.org/AsgardCms/Menu) | [![Build Status](https://travis-ci.org/AsgardCms/Menu.svg?branch=develop)](https://travis-ci.org/AsgardCms/Menu)
| [Workshop](https://github.com/AsgardCms/Workshop)  | [![Build Status](https://travis-ci.org/AsgardCms/Workshop.svg?branch=master)](https://travis-ci.org/AsgardCms/Workshop) | [![Build Status](https://travis-ci.org/AsgardCms/Workshop.svg?branch=develop)](https://travis-ci.org/AsgardCms/Workshop)
| [Media](https://github.com/AsgardCms/Media)  | [![Build Status](https://travis-ci.org/AsgardCms/Media.svg?branch=master)](https://travis-ci.org/AsgardCms/Media) | [![Build Status](https://travis-ci.org/AsgardCms/Media.svg?branch=develop)](https://travis-ci.org/AsgardCms/Media)
| [Block](https://github.com/AsgardCms/Block) | [![Build Status](https://travis-ci.org/AsgardCms/Block.svg?branch=master)](https://travis-ci.org/AsgardCms/Block) | [![Build Status](https://travis-ci.org/AsgardCms/Block.svg?branch=develop)](https://travis-ci.org/AsgardCms/Block)

## Code Quality

Code quality is very important for AsgardCms. I want to make sure everything is clean and appropriate. This is a recap of the quality scores on various services.

| Module (master) | Scrutinizer-ci | Sensiolabs Insights | Code Climate |
| --------------- | -------------- | ------------------- | ------------ |
| Core | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Core/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Core/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/57e26b38-6275-4608-96e2-44047aaed5c2/mini.png)](https://insight.sensiolabs.com/projects/57e26b38-6275-4608-96e2-44047aaed5c2) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Core/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Core) |
| Setting | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Setting/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Setting/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/92d544b4-a3ca-4c2a-9ffd-0741c521cb14/mini.png)](https://insight.sensiolabs.com/projects/92d544b4-a3ca-4c2a-9ffd-0741c521cb14) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Setting/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Setting) |
| Menu | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Menu/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Menu/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/f6ca068c-662b-4606-9bee-262abc858f02/mini.png)](https://insight.sensiolabs.com/projects/f6ca068c-662b-4606-9bee-262abc858f02) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Menu/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Menu) |
| Workshop | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Workshop/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Workshop/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/d6258dc8-cd2a-4288-94a5-8a8089e6609e/mini.png)](https://insight.sensiolabs.com/projects/d6258dc8-cd2a-4288-94a5-8a8089e6609e) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Workshop/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Workshop) |
| Media | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Media/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Media/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/648270bf-8b9c-4994-b006-a948fef307b2/mini.png)](https://insight.sensiolabs.com/projects/648270bf-8b9c-4994-b006-a948fef307b2) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Media/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Media) |

==> Platform-1.0.6.zip: Platform-1.0.6/readme.md <==
[![Latest Stable Version](https://poser.pugx.org/asgardcms/platform/version.svg)](https://packagist.org/packages/asgardcms/platform)
[![Total Downloads](https://poser.pugx.org/asgardcms/platform/downloads.svg)](https://packagist.org/packages/asgardcms/platform)
[![Latest Unstable Version](https://poser.pugx.org/asgardcms/platform/v/unstable.svg)](//packagist.org/packages/asgardcms/platform)
[![License](https://poser.pugx.org/asgardcms/platform/license.svg)](https://packagist.org/packages/asgardcms/platform)

## AsgardCMS Platform

View the documentation at [AsgardCMS.com/docs](http://asgardcms.com/docs/).

Join the conversation on Slack [![Slack](http://slack.asgardcms.com/badge.svg)](http://slack.asgardcms.com/)

## Builds

| Module | Master | Develop |
| ---------------- | --------------- | --------------- |
| [Core](https://github.com/AsgardCms/Core)  | [![Build Status](https://travis-ci.org/AsgardCms/Core.svg?branch=master)](https://travis-ci.org/AsgardCms/Core) | [![Build Status](https://travis-ci.org/AsgardCms/Core.svg?branch=develop)](https://travis-ci.org/AsgardCms/Core)
| [Setting](https://github.com/AsgardCms/Setting)  | [![Build Status](https://travis-ci.org/AsgardCms/Setting.svg?branch=master)](https://travis-ci.org/AsgardCms/Setting) | [![Build Status](https://travis-ci.org/AsgardCms/Setting.svg?branch=develop)](https://travis-ci.org/AsgardCms/Setting)
| [Menu](https://github.com/AsgardCms/Menu)  | [![Build Status](https://travis-ci.org/AsgardCms/Menu.svg?branch=master)](https://travis-ci.org/AsgardCms/Menu) | [![Build Status](https://travis-ci.org/AsgardCms/Menu.svg?branch=develop)](https://travis-ci.org/AsgardCms/Menu)
| [Workshop](https://github.com/AsgardCms/Workshop)  | [![Build Status](https://travis-ci.org/AsgardCms/Workshop.svg?branch=master)](https://travis-ci.org/AsgardCms/Workshop) | [![Build Status](https://travis-ci.org/AsgardCms/Workshop.svg?branch=develop)](https://travis-ci.org/AsgardCms/Workshop)
| [Media](https://github.com/AsgardCms/Media)  | [![Build Status](https://travis-ci.org/AsgardCms/Media.svg?branch=master)](https://travis-ci.org/AsgardCms/Media) | [![Build Status](https://travis-ci.org/AsgardCms/Media.svg?branch=develop)](https://travis-ci.org/AsgardCms/Media)
| [Block](https://github.com/AsgardCms/Block) | [![Build Status](https://travis-ci.org/AsgardCms/Block.svg?branch=master)](https://travis-ci.org/AsgardCms/Block) | [![Build Status](https://travis-ci.org/AsgardCms/Block.svg?branch=develop)](https://travis-ci.org/AsgardCms/Block)

## Code Quality

Code quality is very important for AsgardCms. I want to make sure everything is clean and appropriate. This is a recap of the quality scores on various services.

| Module (master) | Scrutinizer-ci | Sensiolabs Insights | Code Climate |
| --------------- | -------------- | ------------------- | ------------ |
| Core | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Core/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Core/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/57e26b38-6275-4608-96e2-44047aaed5c2/mini.png)](https://insight.sensiolabs.com/projects/57e26b38-6275-4608-96e2-44047aaed5c2) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Core/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Core) |
| Setting | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Setting/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Setting/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/92d544b4-a3ca-4c2a-9ffd-0741c521cb14/mini.png)](https://insight.sensiolabs.com/projects/92d544b4-a3ca-4c2a-9ffd-0741c521cb14) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Setting/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Setting) |
| Menu | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Menu/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Menu/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/f6ca068c-662b-4606-9bee-262abc858f02/mini.png)](https://insight.sensiolabs.com/projects/f6ca068c-662b-4606-9bee-262abc858f02) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Menu/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Menu) |
| Workshop | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Workshop/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Workshop/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/d6258dc8-cd2a-4288-94a5-8a8089e6609e/mini.png)](https://insight.sensiolabs.com/projects/d6258dc8-cd2a-4288-94a5-8a8089e6609e) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Workshop/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Workshop) |
| Media | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/AsgardCms/Media/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/AsgardCms/Media/?branch=master) | [![SensioLabsInsight](https://insight.sensiolabs.com/projects/648270bf-8b9c-4994-b006-a948fef307b2/mini.png)](https://insight.sensiolabs.com/projects/648270bf-8b9c-4994-b006-a948fef307b2) | [![Code Climate](https://codeclimate.com/github/AsgardCms/Media/badges/gpa.svg)](https://codeclimate.com/github/AsgardCms/Media) |
